# Supports Organizer.rb
=begin rdoc
= Faces into Componennts
Copyright 2009, Chris Fullmer
All Rights Reserved

== Disclaimer
THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES,
INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
FOR A PARTICULAR PURPOSE.

== License
This software is distributed under the Smustard End User License Agreement
http://www.smustard.com/eula

== Information
Author:: Chris Fullmer
Organization:: www.ChrisFullmer.com and distributed on sketchucation.com
Name:: Faces into Componennts
Version:: 1.2
SU Version:: I developed this on v7, but old versions should work.
Date:: September 27, 2009
Description:: This script will turn each selected face into a separate component.
Usage::  Select faces to be turned into individual components.  Then run the plugin from "Plugins>Chris Fullmer Tools>Faces into Groups
Requires:: No additional Scripts
History::
1.0:: 2009-03-23
   * Original release.  
1.1:: 2009-03-23
   * Added the plugin to the right click context menu.
1.2:: 2009-09-27
   * There were issues that were causing the scrip to crash.  It appears to have to do with curves and arcs.  The script now explodes all arcs and curves before making the components.  It seems to work now.
=end
require 'sketchup.rb'

module Clf_face_to_component
	def Clf_face_to_component.main
		model = Sketchup.active_model
		entities = model.active_entities
		selection = model.selection
		if selection.length == 0
			UI.messagebox "Please select faces to turn into groups before running this plugin."
			return
		end
		faces = []
		edges = []
		
		selection.each do |e| 
			faces << e if e.is_a? Sketchup::Face
			if e.is_a? Sketchup::Edge
				edges << e if e.curve
			end
		end
		
		if faces.length == 0
			UI.messagebox "There were no faces selected."
			return
		end
		
		a = Sketchup.version
		b = a[0,1].to_i
		if b > 6
			model.start_operation("Faces into Components", true)
		else
			model.start_operation("Faces into Components")
		end
		
		edges.each do |e|
			e.explode_curve
		end
		
		faces.each do |e|
			group = entities.add_group( e )
			group.to_component
		end
		model.commit_operation
	end
end


if( $submenu )
	organizer = $submenu 
	if !file_loaded?(__FILE__) then
		organizer.add_item("Faces into Components") { Clf_face_to_component.main }
	end
else
	if !file_loaded?('clf_menu_loader') then
		$clf_tools_menu = UI.menu("Plugins").add_submenu("Chris Fullmer Tools")
	end
	if !file_loaded?(__FILE__) then
		$clf_tools_menu.add_item("Faces into Components") { Clf_face_to_component.main }
	end
end

 # Right click on anything to see a Hello World item.
 UI.add_context_menu_handler do |context_menu|
   context_menu.add_item("Faces into Components") { Clf_face_to_component.main }
 end
 
file_loaded('clf_menu_loader')
file_loaded(__FILE__)